!##############################################################       
!     MakeGeo: 
!       + Create a GMSH .geo file from a 2 ascii files containing ordered
!       points forming the contour of the domain 
!        (1 file for the front = BC 1; 1 file for the side of the drainage basin = BC 2)
!
!       + Particularity here, assume that the contour is in stereopolar projection with ref meridien 39W
!         I. Joughin velocity data sets use 45W => re-project the contour points
!       + The reverse projection (45W => 39W ) is made in  MeshToElmer_Greenland.f90
!
! INPUT : "../Data/ContourCote.dat" and "../Data/ContourSide.dat" (contains x,y coordinate of the contour points)
! OUTPUT: "Contour.geo" (GMSH .geo file)
!
!  Author : F. Gillet-Chaulet; LGGE, Grenoble
!##############################################################       
       program MakeGeo
       implicit none
       INTEGER, PARAMETER :: dp = SELECTED_REAL_KIND(12)
       real(dp) :: pi
       real(dp)   :: x,y,x1,y1,lat,lon,zero
       real(dp) :: lc=2500.0
       integer :: np
       integer :: i,j
       integer :: compt,compt1
       character*100 :: uxcom,test
       character*1 :: dumy

       pi=Dacos(-1.0_dp)


! Create Contour.geo from the Contour files
       open(11,file='Contour.geo')
       write(11,'(A)') 'Mesh.Algorithm=5;'

       Open(10,file='../Data/ContourCote.dat')
       compt=0
       do while (.true.)
        read (10,*,end=300) x,y
        call xy2LatLon(lat,lon,71.0_dp*pi/180._dp,-39._dp*pi/180._dp,x,y)
        call LatLon2xy(lat,lon,70.0_dp*pi/180._dp,-45._dp*pi/180._dp,x1,y1)
        compt=compt+1
        write(11,1000) compt,x1,y1,lc
       end do

 300 continue
       close(10)
       compt1=compt

       Open(10,file='../Data/ContourSide.dat')
       do while (.true.)
        read (10,*,end=301) x,y
        call xy2LatLon(lat,lon,71.0_dp*pi/180._dp,-39._dp*pi/180._dp,x,y)
        call LatLon2xy(lat,lon,70.0_dp*pi/180._dp,-45._dp*pi/180._dp,x1,y1)
        compt=compt+1
        write(11,1000) compt,x1,y1,lc
       end do

 301 continue
       close(10)

       write(11,'(A)',advance='no') 'Spline(1)={'
       Do i=1,compt1
        if (i.lt.compt1) then 
                write(11,'(i6,A)',advance='no') i,','
        else
                write(11,'(i6,A)') i,'};'
        end if
       End do

       write(11,'(A)',advance='no') 'Spline(2)={'
       write(11,'(i6,A)',advance='no') compt1,','
       Do i=compt1+1,compt
                 write(11,'(i6,A)',advance='no') i,','
       End do
       write(11,'(i6,A)') 1,'};'


       write(11,'(A)') 'Line Loop(3)={1,2};'
       write(11,'(A)') 'Plane Surface(4)={3};'
       write(11,'(A)') 'Physical Line(100)={1};'
       write(11,'(A)') 'Physical Line(101)={2};'
       write(11,'(A)') 'Physical Surface(102)={4};'

       close(11)


 1000  format('Point(',i6,')={',e14.7,',',e14.7,', 0.0 ,', e14.7,'};')


       End
